@@ -1,5 +1,5 @@
 #import <objectbase/SwarmObject.h>
-#import "MemLogConsumer.h"
+#import <logzone/MemLogConsumer.h>
 
 @interface RMemLogger: SwarmObject <MemLogConsumer>
 {
