@@ -36,6 +36,17 @@
   return [super createEnd];
 }
 
+- (int) compare: otherId
+{
+	long l1, l2;
+
+	if (self == otherId) return 0;
+	sscanf ([self getText], "%*s %ld ", &l1);
+	sscanf ([otherId getText], "%*s %ld ", &l2);
+	if (l1>l2) return -1;
+	return l1<l2;
+}
+
 - (const char*) getText
 {
   return [str getC];
